@@ -171,6 +171,14 @@ class YandexParser(object):
             query = query.replace('&nbsp;', ' ')
             return query
 
+        match = re.search(
+            r'<input class="[^"]*?mini-suggest__input[^"]*?"[^>]+?value="([^"]*)"',
+            self.content
+        )
+        if match:
+            query = match.group(1).replace('&nbsp;', ' ')
+            return query
+
         raise YandexParserError(u'не удалось найти текущий запрос')
 
     def get_current_query(self):
